import remoteapi
import ScenarioHelper

"""
TestEntityHook.py

Unit test for Remote API that creates a single client and executes
several entity-based PISimdis commands remotely.  It creates a
scenario with two Platforms, and alternately hooks/unhooks those Platforms
"""

# Sets the hooked status of a given Platform, then verifies that the current status matches
def hookAndVerify(localId, hooked):
	f = piSimdis.setEntityHooked(localId, hooked)
	if not f.isOk(1000):
		raise Exception("hookAndVerify(): Failed to hook entity")
	f = piSimdis.isEntityHooked(localId)
	if not f.isOk(1000):
		raise Exception("hookAndVerify(): Failed to fetch hook status")
	if (f.value() != hooked):
		raise Exception("hookAndVerify(): Returned hook status does not match")

# Checks that the current number of hooked entities matches the provided number
def verifyHookedCount(number):
	f = piSimdis.getEntityHooks()
	if not f.isOk(1000):
		raise Exception("verifyHookedCount(): Failed to get entity count")
	if (len(f.value()) != number):
		raise Exception("verifyHookedCount(): Returned entity count does not match")

# Calls piSimdis.unhookAllEntities and verifies that the number of hooked entities is now zero
def unhookAllEntities():
	f = piSimdis.unhookAllEntities()
	if not f.isOk(1000):
		raise Exception("unhookAllEntities(): Failed to unhook entities")
	verifyHookedCount(0)

client = remoteapi.DiscoveryClient().createClient()

if client is None:
	raise Exception("Failed to connect.")

pi = client.pluginApi()
piSimdis = pi.simdis()
piData = pi.data()

pi.config().setResponsesEnabled(True)

# Configure the Scenario with two Platforms
ScenarioHelper.newScenario(piData)
ScenarioHelper.createPlatform(client, 10, [0,0,0], "Python Platform 1")
ScenarioHelper.createPlatform(client, 20, [0,0,0], "Python Platform 2")

verifyHookedCount(0)
hookAndVerify(10, True)
verifyHookedCount(1)
hookAndVerify(20, True)
verifyHookedCount(2)
hookAndVerify(20, False)
verifyHookedCount(1)
unhookAllEntities()

client.close()
print("Test Successful")