import time
import RemoteApi_pb2
import remoteapi
import sys

"""
TestLandmark.py

Unit test for Remote API using Python that functions
related to PISim3dLandmark.
"""

client = remoteapi.DiscoveryClient().createClient()
if client is None:
	raise Exception("Failed to connect.")

pi = client.pluginApi()
piSimdis = pi.simdis()

f = piSimdis.createSim3dLandmark([22,159,0], [0,0,0], "x", False, [1,1,1], -1.0, -1.0, "Test Label String 1")
if not f.isOk(1000):
	raise Exception("Failed createSim3dLandmark")
id = f.value()

# Wait 3 seconds to make note of the position
time.sleep(3)

f = piSimdis.updateSim3dLandmark(id, [22,165,0], [0,0,0], "x", False, [1,1,1], -1.0, -1.0, "Test Label String 2")
if not f.isOk(10000):
	raise Exception("Failed updateSim3dLandmark")

# Wait 3 more seconds to verify the landmark has moved and the text has changed
time.sleep(3)

f = piSimdis.getSim3dLandmark(id)
if not f.isOk(1000):
	raise Exception("Failed getSim3dLandmark")
# Just check that the label string is correct
assert(f.value().labelString == "Test Label String 2")

f = piSimdis.setSim3dLandmarkColor(id, True, 0xFF0000FF)
if not f.isOk(1000):
	raise Exception("Failed setSim3dLandmarkColor")

f = piSimdis.getSim3dLandmarkOverrideColor(id)
if not f.isOk(1000):
	raise Exception("Failed getSim3dLandmarkOverrideColor")
assert(f.value().useOverride == True)
assert(f.value().color == 0xFF0000FF)

f = piSimdis.setLandmarkPreference(id, "icon", "o")
if not f.isOk(1000):
	raise Exception("Failed setLandmarkPreference")

f = piSimdis.getLandmarkPreference(id, "icon")
if not f.isOk(1000):
	raise Exception("Failed getLandmarkPreference")
assert(f.value() == "o")

f = piSimdis.removeSim3dLandmark(id)
if not f.isOk(1000):
	raise Exception("Failed removeSim3dLandmark")

client.close()
print("Test successful")
