import RemoteApi_pb2
import remoteapi
import sys

"""
TestLoadDataFile.py

Unit test for Remote API that loads a single data file.
NOTE: File Reader, File Writer, and HDF5 plug-ins are
required for this test to succeed
"""
def WaitForOK(f, waitAmount):
	secondsRemaining = waitAmount
	# Only wait 1 second at a time, printing a '.' each second
	while secondsRemaining > 0 and not f.waitForResponse(1000):
		secondsRemaining -= 1
		sys.stdout.write('.')
		sys.stdout.flush()
		# Break out if we got a negative response
		if f.responseReceived():
			break

	if not f.isOk(0):
		raise Exception("Command Failed")

	if secondsRemaining != waitAmount:
		print("")

client = remoteapi.DiscoveryClient().createClient()
if client is None:
	raise Exception("Failed to connect.")

pi = client.pluginApi()
piData = pi.data()
piSimdis = pi.simdis()
waitAmount = 45

f = piData.deleteScenario()
if not f.isOk(1000):
	raise Exception("Failed deleteScenario")

# Load data file is unique because it can take a while to respond...
f = piData.loadDataFile("$(SIMDIS_DIR)/demos/SIMDIS/import/animatedLine.asi")
print("Requested load of data file, waiting up to " + str(waitAmount) + " seconds")
WaitForOK(f, waitAmount)

# Ensure the scenario got loaded properly with a find-platform
f = piData.findPlatform('Plane')
if not f.isOk(1000) or f.value() == 0:
	raise Exception("Failed findPlatform")

# Now save an HDF5 File
f = piSimdis.saveDataFile("$(SIMDIS_HOME)/TestFileSafeToDelete.hdf5", {'Compression' : 'True'})
print("")
print("Requested saving of data file, waiting up to " + str(waitAmount) + " seconds")
WaitForOK(f, waitAmount)
print("Check that the file $(SIMDIS_HOME)/TestFileSafeToDelete.hdf5 exists")

# Now save an ASI file
f = piSimdis.saveDataFile("$(SIMDIS_HOME)/TestFileSafeToDelete.asi", {'FilePathType' : 'Absolute'})
print("")
print("Requested saving of data file, waiting up to " + str(waitAmount) + " seconds")
WaitForOK(f, waitAmount)
print("Check that the file $(SIMDIS_HOME)/TestFileSafeToDelete.asi exists")

# Now save a Zip file
f = piSimdis.saveDataFile("$(SIMDIS_HOME)/TestFileSafeToDelete.zip", {})
print("")
print("Requested saving of data file, waiting up to " + str(waitAmount) + " seconds")
WaitForOK(f, waitAmount)
print("Check that the file $(SIMDIS_HOME)/TestFileSafeToDelete.zip exists")

# Test loading a media file
f = piSimdis.loadMediaFile("$(SIMDIS_DIR)/demos/SIMDIS/SIMDISMediaPlayer/video/clock.wmv")
WaitForOK(f, waitAmount)

client.close()
print("Test successful")
